![POLITICO](https://rawgithub.com/The-Politico/src/master/images/logo/badge.png)

# django-crosswalk

Build and query databases of arbitrary entities.

See the docs on [readthedocs](http://django-crosswalk.readthedocs.io/en/latest/).
